From 9c77432a6228f369e72a260b1baa8bcf62af830a Mon Sep 17 00:00:00 2001
From: Peter Rotich <peter@osticket.com>
Date: Wed, 28 Nov 2012 12:34:34 -0500
Subject: [PATCH] Fix assigned comments variable

---
 include/upgrader/sql/00ff231f-c2a64ea4.patch.sql | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/include/upgrader/sql/00ff231f-c2a64ea4.patch.sql b/include/upgrader/sql/00ff231f-c2a64ea4.patch.sql
index 8b19f55e8..d90d48130 100644
--- a/include/upgrader/sql/00ff231f-c2a64ea4.patch.sql
+++ b/include/upgrader/sql/00ff231f-c2a64ea4.patch.sql
@@ -2,12 +2,16 @@
  * @version v1.7 RC4
  * @signature c2a64ea46d1fb749f5d908820bb813a0
  *
  * Supports starts- and ends-with in email filter rules
  *  
  */
 
 ALTER TABLE  `%TABLE_PREFIX%filter_rule` CHANGE  `how`  `how` ENUM(  'equal',
-    'not_equal',  'contains',  'dn_contain',  'starts',  'ends' )
+    'not_equal',  'contains',  'dn_contain',  'starts',  'ends' );
+
+-- %message
+UPDATE `%TABLE_PREFIX%email_template`
+    SET `assigned_alert_body` = REPLACE(`assigned_alert_body`, '%message', '%{comments}');
 
 UPDATE `%TABLE_PREFIX%config`
     SET `schema_signature`='c2a64ea46d1fb749f5d908820bb813a0';
@@ -2,12 +2,16 @@
  * @signature c2a64ea46d1fb749f5d908820bb813a0
  *
- * Supports starts- and ends-with in email filter rules
- *  
+ *  - Supports starts- and ends-with in ticket filter rules
+ *  - Fix assigned template variable
  */
 
-- 
GitLab